@@ -81,7 +81,9 @@ class ConnectionBase(object):
             self._logger = logging.getLogger(self.name)
         else:
             self._logger = logging.getLogger(type(self).__name__)
-        self._logger.debug("hi.")
+        # make sure a pexpect object is created
+        self.exp != False
+        self.log("hi.")
 
     def log(self, msg):
         self._logger.debug(msg)
@@ -91,22 +93,25 @@ class ConnectionBase(object):
         """ the pexpect object - Don't bother with this if you don't know what
                                  it means.
         """
+        self.log("retrieve pexpect object")
         try:
             return self._exp
         except AttributeError as e:
+            self.log("have no pexpect object yet")
             self._exp = self._get_exp()
             return self._exp
 
     def _expect(self, pattern, timeout=-1, searchwindowsize=-1):
         """ a wrapper for :pexpect:meth:`spawn.expect`
         """
-        self._logger.debug("expect({},{},{})".format(
+        self.log("expect({},{},{})".format(
             str(pattern).encode('string-escape'), timeout, searchwindowsize))
         try:
             self.exp.expect(pattern, timeout, searchwindowsize)
-            self._logger.debug("expect succeeded.")
+            self.log("expect succeeded.")
         except Exception as e:
-            self._logger.debug("expect failed.")
+            self.log("expect failed.")
+            self._logger.exception(e)
             raise e
 
     def _send(self, s):
@@ -179,9 +184,9 @@ class ConnectionBase(object):
         ))
         return self.exp.before
 
-    def __del__(self):
-        self._logger.debug("bye.")
-        self.exp.close()
+    def close(self):
+        self.log("force pexpect object to close")
+        self.exp.close(force=True)
 
 class SerialConn(ConnectionBase):
     """ implements a serial connection.
@@ -279,7 +284,8 @@ class BCC(ConnectionBase):
     def login(self,*args,**kwargs):
         try:
             super(BCC,self).login(*args,**kwargs)
-        except pexpect.EOF:
+        except pexpect.EOF as e:
+            self._logger.exception(e)
             raise BccException("EOF found. Did you configure the correct port?")
 
     def _get_exp(self):
